@@ -22,8 +22,11 @@
 #define _(S) S
 
 /* forward decls for circular referencing types */
-typedef struct _GtkMozEdit GtkMozEdit;
+typedef struct _GmeCommandManager GmeCommandManager;
+typedef struct _GmeCommandParams GmeCommandParams;
+typedef struct _GmeObserver GmeObserver;
 typedef struct _GmeSupports GmeSupports;
 typedef struct _GmeWebBrowser GmeWebBrowser;
+typedef struct _GmeHTMLView GmeHTMLView;
 
 #endif /* __GME_FORWARD_H__ */
